@@ -117,10 +117,13 @@ spell.check.dictionary <- function (check, dictionary, part.resp, tolerance = 1)
     #########################
     
     ####progress bar####
-    pb <- tcltk::tkProgressBar(title = "R progress bar", label = "Spell-check progress",
-                  min = 0, max = length(incorrect), initial = 0, width = 300)
-    invisible(tcltk::getTkProgressBar(pb))
-    count <- 0
+    if(Sys.info()["sysname"] == "Windows")
+    {
+        pb <- tcltk::tkProgressBar(title = "R progress bar", label = "Spell-check progress",
+                                   min = 0, max = length(incorrect), initial = 0, width = 300)
+        invisible(tcltk::getTkProgressBar(pb))
+        count <- 0
+    }
     ####progress bar####
     
     #initialize check for saving appendix dictionary
@@ -310,15 +313,19 @@ spell.check.dictionary <- function (check, dictionary, part.resp, tolerance = 1)
         {rem.resp <- wcw$rem.resp}
         
         ####progress bar####
-        count <- count + 1
-        percent <- floor((count/length(incorrect))*100)
-        info <- sprintf(paste(count, "of", length(incorrect), "words done"), percent)
-        tcltk::setTkProgressBar(pb, count, sprintf("Spell-check Progress (%s)", info), info)
+        if(Sys.info()["sysname"] == "Windows")
+        {
+            count <- count + 1
+            percent <- floor((count/length(incorrect))*100)
+            info <- sprintf(paste(count, "of", length(incorrect), "words done"), percent)
+            tcltk::setTkProgressBar(pb, count, sprintf("Spell-check Progress (%s)", info), info)
+        }
         ####progress bar####
     }
     
     ####progress bar####
-    close(pb)
+    if(Sys.info()["sysname"] == "Windows")
+    {close(pb)}
     ####progress bar####
     
     #if any words were added to the appendix dictionary,
@@ -350,12 +357,15 @@ spell.check.dictionary <- function (check, dictionary, part.resp, tolerance = 1)
     }
     
     #secondary monikers if animals dictionary
-    if(length(misnom)!=0)
+    if(any(dictionary %in% SemNetDictionaries::dictionaries(TRUE)))
     {
-        #check for monikers
-        for(i in 1:length(to))
-            for(j in 1:length(to[[i]]))
-        {to[[i]][j] <- SemNetCleaner::moniker(to[[i]][j],misnom)}
+        if(length(misnom)!=0)
+        {
+            #check for monikers
+            for(i in 1:length(to))
+                for(j in 1:length(to[[i]]))
+                {to[[i]][j] <- SemNetCleaner::moniker(to[[i]][j],misnom)}
+        }
     }
     
     #secondary search for words to combine
